%Q9 Skydiver question
function Q9_skydiver
g = 9.81;  %Strength of gravity /Nkg^-2
cD = 0.4;  %Drag coefficient
m = 100;   %Mass of skydiver
h0 = 10e3;  %Drop atitude (from rest) /m
hp = 2000; %Parachute deployment altitude /m
As = 2.0;  %Skydiver cross sectional area during freefall /m^2
Ap = pi*(7.14^2);  %Parachute cross sectional area /m^2
tp = 10;  %Time in seconds to deploy parachute
dt = 0.1; %Verlet timestep /s
fsize = 14;

%Initialize outputs
x = 0; v = 0; a = g; h = h0; n=1; t = 0; tdeploy=0;

%Perform Verlet method to calculate development of kinematic parameters
%with time
while ( h(n) > 0 )
    t(n+1) = t(n) + dt;
    if h(n) <=hp
        %Deploy parachute over tp seconds
        A = As + (Ap-As)*tdeploy/tp;
        tdeploy = tdeploy + dt;
        if tdeploy >= tp
            %Make sure A doesn't exceed Ap
            tdeploy = tp;
        end
    else
        A = As;
    end
    alpha = g - 0.5 * cD * rho_air( h(n) ) * A * ( v(n)^2 ) /m;
    x(n+1) = x(n) + v(n)*dt + 0.5*alpha*( dt^2 );
    h(n+1) = h0 - x(n+1);
    V = v(n) + alpha*dt;
    beta = g - 0.5 * cD * rho_air( h(n+1) ) * A * (V^2) /m;
    v(n+1) = v(n) + 0.5*( alpha + beta )*dt;
    a(n+1) = g - 0.5 * cD * rho_air( h(n+1) ) * A * ( v(n+1)^2 ) /m;
    n = n+1;
end
tfall = t(n);
vland = v(n);

%Plot graphs
figure( 'units','normalized','position',[0,0,1,1] );
subplot( 3,1,1); grid on;
plot( t, h/1e3 ); set(gca,'fontsize',fsize); grid on; xlabel('time /s'); ylabel('altitude /km');
xlim([0,tfall]);
title(['Skydive! m=',num2str(m),'kg, A=',num2str(As,3),'m^2, A_p=',...
    num2str(Ap,3),'m^2, c_D=',num2str(cD),', \Deltat=',num2str(dt),', t_{fall}=',num2str(tfall,3)...
    's, t_{deploy}=',num2str(tp),'s, v_{land}=',num2str(vland,3),'m/s.']);
subplot( 3,1,2); grid on;
plot( t, v ); set(gca,'fontsize',fsize); grid on; xlabel('time /s'); ylabel('velocity /ms^{-1}');
xlim([0,tfall]);
subplot( 3,1,3); grid on;
plot( t, a ); set(gca,'fontsize',fsize); grid on; xlabel('time /s'); ylabel('acceleration /ms^{-2}');
xlim([0,tfall]);
print(gcf,'skydive.png','-r300','-dpng');

%%

%Density of air /kgm^-3 with altitude h/m
function rho = rho_air(h)
rho = 1.225*exp( -h/10400 );

%End of code